==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/box.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] =
"$Id: box.c,v 1.10 2004/04/20 13:16:53 lwa Exp $";

#include "config.h"

#include <ctype.h>
#include <string.h>

/*
 *  convert mailbox into directory name
 */

char *getbox(char *box) {
  char *lastdot;
  char *thebox=box;

  if (*box==0)
    return box;
  if (strcasecmp(box, "Inbox")==0) {
    *thebox=0;
    return thebox;
  }

  lastdot=box-1;
  while(*box) {
    if (iscntrl(toascii(*box))) {
      *thebox=0;
      return thebox;
    }
    if (*box == '/')
      *box='.';
    if (*box == '.') {
      if (lastdot==box-1) {
	*thebox=0;
	return thebox;
      }
      lastdot=box;
    }
    if (box-thebox > 64) { 
      *box=0;
      return thebox;
    }
    box++;
  }
  return thebox;
}

==> lmtpd-0.10.4.tar.gz: lmtpd-0.10.4/box.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED =
"$Id: box.c,v 1.11 2004/10/26 09:59:19 lwa Exp $";



#include <ctype.h>
#include <string.h>

/*
 *  convert mailbox into directory name
 */

char *getbox(char *box) {
  char *lastdot;
  char *thebox=box;

  if (*box==0)
    return box;
  if (strcasecmp(box, "Inbox")==0) {
    *thebox=0;
    return thebox;
  }

  lastdot=box-1;
  while(*box) {
    if (iscntrl(toascii(*box))) {
      *thebox=0;
      return thebox;
    }
    if (*box == '/')
      *box='.';
    if (*box == '.') {
      if (lastdot==box-1) {
	*thebox=0;
	return thebox;
      }
      lastdot=box;
    }
    if (box-thebox > 64) { 
      *box=0;
      return thebox;
    }
    box++;
  }
  return thebox;
}
